<?php
/*

   GOpdc: config.inc - Configuration parser for GOpdc 

   Author: Jan Wenzel    <jan.wenzel@GONICUS.de>

Copyright (C) 2005,2006,2007 GONICUS GmbH

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
    USA

 Contact information: GONICUS GmbH
                      Moehnestrasse 11-17
                      D-59755 Arnsberg
                      Germany
                      tel: ++49 2932 916 0
                      fax: ++49 2932 916 230
                      email: info@GONICUS.de
                      http://www.GONICUS.de
*/


/** Configuration File */
$file = '/etc/gopdc.xml';

// Set needed storage arrays
$tag_tree = array();
$option = array();
$config = array();

/** 
 * Class for configuration Tags in XML DOM.
 */
class tag {
	/** 
     * The Name of the Tag (Option Name)
	 * Example Entry <option name="ux_uid" ... />
     */
	var $name;
	
	/** 
	 * Value of the Tag (Option Value) 
     * Example Entry <option ... value="1001"/> 
	 */
	var $attributes;
	
	/** Children of this Tag (Tree Structure) */
	var $children;
	
	/**
     * Parametrized Constructor.
     * @param $name name for new tag
     * @param $attributes value for new tag
     * @param $children children of new tag
     */
	function tag($name, $attributes, $children) {
		$this->name = $name;
		$this->attributes = $attributes;
		$this->children = $children;
	}

	/**
     * Returns $this->name
     * @return $this->name
     */
	function getName() {
		return $this->name;
	}

    /**
     * Returns $this->attributes
     * @return $this->attributes
     */
	function getAttributes() {
		return $this->attributes;
	}

	/**
     * @return true if this tag has children, false otherwise
     */
	function hasChildren() {
		return (isset($this->children));
	}

	/**
	 * @return $this->children
	 */
	function getChildren() {
		return $this->children;
	}
}

/**
 * Called when new Tag has been detected (by opening <). Pushes
 * Attributes to storage array $option, when $name is OPTION.
 * @param $parser XML-Parser instance to use
 * @param $name Name of this Tag
 * @param $attributes Values that are defined by tag
 */
function startTag($parser, $name, $attributes) {
	global $tag_tree, $option;
	
	// Create new leaf ($children is empty)
	$tag = new tag($name, $attributes, '');
	
	if($tag->getName() == 'OPTION') {
		$attr=$tag->getAttributes();
		array_push($option, $attr);
	}
}

/**
 * Empty function that is called when tag is closed (by closing />).
 * Don't need to do something here but is kept for compatibility issues.
 */
function endTag($parser, $name) {
	// Do nothing here
}

/**
 * Returns Value for given Option $name
 * @param $name option name
 * @return value for option if exists, -1 otherwise
 */
function getOption($name) {
	global $option;
	foreach($option as $key => $value) {
		if($value['NAME'] == $name) {
			
			// Do special handling for boolean values
			// (Return real bools)
			if ($value['VALUE'] == 'false') {
				return false;
			} else if ($value['VALUE'] == 'true') {
				return true;
			} else {
				return $value['VALUE'];
			}
		}
	}
}

/**
 * Returns a real value for a given Option $name
 * @param $name option name
 * return value for option
 */
function myOption($name){
	GLOBAL $default_ar;
	$value=getOption($name);
	if($value){
		return($value);
	} else {
		return($default_ar[$name]);
	}
}


// Do real Parsing now
$xml_parser = xml_parser_create();
xml_parser_set_option($xml_parser, XML_OPTION_CASE_FOLDING, true);
xml_set_element_handler($xml_parser, "startTag", "endTag");

$data = xml_parse($xml_parser, file_get_contents($file));
if(!$data) {
	die(sprintf("XML error: %s at line %d",
		xml_error_string(xml_get_error_code($xml_parser)),
		xml_get_current_line_number($xml_parser)));
}
xml_parser_free($xml_parser);
// vim:tabstop=2:expandtab:shiftwidth=2:filetype=php:syntax:ruler:
?>
